package VMOMI::HostCpuPowerManagementInfoPolicyType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
